.. currentmodule:: larch

========
DataTree
========

.. autosummary::
    :toctree: generated/

    DataTree


Attributes
----------

.. autosummary::
    :toctree: generated/

    DataTree.root_node_name
    DataTree.subspaces
    DataTree.relationships_are_digitized
    DataTree.n_cases
    DataTree.n_alts
    DataTree.CASEID
    DataTree.ALTID


Methods
-------

.. autosummary::
    :toctree: generated/

    DataTree.add_dataset
    DataTree.add_relationship
    DataTree.digitize_relationships
    DataTree.query_cases
    DataTree.replace_datasets
    DataTree.setup_flow
